[Pkg-javascript-commits] [pdf.js] 182/204: Bug 1071709 - 5-30% TART / Session Restore regressions on Inbound (v.35) september 22 from rev d3a7f765152f

David Prévot taffit at moszumanska.debian.org
Sat Oct 25 18:50:49 UTC 2014


This is an automated email from the git hooks/post-receive script.

taffit pushed a commit to branch master
in repository pdf.js.

commit fc3721ce2d8ca313746365e5c77d2ede81e4fa65
Author: Jim Mathies <jmathies at mozilla.com>
Date:   Fri Oct 10 23:02:49 2014 +0200

    Bug 1071709 - 5-30% TART / Session Restore regressions on Inbound (v.35) september 22 from rev d3a7f765152f
---
 extensions/firefox/content/pdfjschildbootstrap.js | 9 ++++++---
 1 file changed, 6 insertions(+), 3 deletions(-)

diff --git a/extensions/firefox/content/pdfjschildbootstrap.js b/extensions/firefox/content/pdfjschildbootstrap.js
index c9758b3..737a490 100644
--- a/extensions/firefox/content/pdfjschildbootstrap.js
+++ b/extensions/firefox/content/pdfjschildbootstrap.js
@@ -15,7 +15,7 @@
 * limitations under the License.
 */
 /* jshint esnext:true */
 /* globals Components, PdfjsContentUtils, PdfJs */
 
 'use strict';
 
@@ -24,11 +24,14 @@
  * initializing our built-in version of pdfjs when running remote.
  */
 
+Components.utils.import('resource://gre/modules/Services.jsm');
 Components.utils.import('resource://pdf.js/PdfJs.jsm');
 Components.utils.import('resource://pdf.js/PdfjsContentUtils.jsm');
 
 // init content utils shim pdfjs will use to access privileged apis.
 PdfjsContentUtils.init();
 
-// register various pdfjs factories that hook us into content loading.
-PdfJs.updateRegistration();
+if (Services.appinfo.processType === Services.appinfo.PROCESS_TYPE_CONTENT) {
+  // register various pdfjs factories that hook us into content loading.
+  PdfJs.updateRegistration();
+}
@@ -15,7 +15,7 @@
 */
 /* jshint esnext:true */
-/* globals Components, PdfjsContentUtils, PdfJs */
+/* globals Components, PdfjsContentUtils, PdfJs, Services */
 
 'use strict';

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-javascript/pdf.js.git



More information about the Pkg-javascript-commits mailing list